---
title: The Marvin Community
description: Join us!
icon: sparkles
---


![](/assets/img/quotes/sort_of_thing_you_enjoy.png)

We're thrilled you're interested in Marvin! Here, we're all about community. We're driven by a shared passion for making LLMs and agents more accessible and easier to use.

### Connect on Discord

Join us on [Discord](https://discord.gg/Kgw4HpcuYG) or [Slack](https://communityinviter.com/apps/prefect-community/prefect-community) to ask questions, share ideas, or just chat with like-minded developers. Don't be shy.

### Contributing to Marvin

We encourage all types of contributions, whether it be reporting bugs, suggesting features, or contributing code. Here's how you can contribute:

- **Issues:** Encountered a bug? Have a suggestion? Open an issue in our [GitHub repository](https://github.com/PrefectHQ/Marvin). We appreciate your input!

- **Pull Requests (PRs):** Ready to contribute code? We welcome your pull requests! Not sure how to make a PR? Check out the [GitHub guide](https://docs.github.com/en/github/collaborating-with-issues-and-pull-requests/about-pull-requests).

- **Discussions:** Have an idea but not quite ready to open an issue or PR? Create a GitHub Discussion.

- **Chat:** Join us in one of the above places to chat about ideas or behavior.
